==> victor1890-0.0.4.tgz: package/README.md <==

## I'm **Victor J. Rosario V**


<div align='left'>
    <a href = "mailto:victorrosariodeveloper@gmail.com">
        <img src="https://img.shields.io/badge/-Gmail-%23333?style=for-the-badge&logo=gmail&logoColor=white" target="_blank">
    </a>
    <a href="https://www.linkedin.com/in/victor-j-rosario-v" target="_blank">
        <img src="https://img.shields.io/badge/-LinkedIn-%230077B5?style=for-the-badge&logo=linkedin&logoColor=white" target="_blank">
    </a>
    <a href='https://drive.google.com/file/d/1gNDOPcef5Q43_i40sR1YLPLoWuYDHwml/view?usp=sharing'>
        <img src='https://img.shields.io/badge/RESUME-CV-red?style=for-the-badge&logo=gmail&logoColor=white' target='_blank'/>
    </a>
</div>


<div align='right'>
    <img src="https://media.giphy.com/media/M9gbBd9nbDrOTu1Mqx/giphy.gif" width="150">
    <a href="https://app.daily.dev/Victor1890">
        <img src="https://api.daily.dev/devcards/773872eaf8514c99bbe1e8b17d69796b.png?r=p1o" width="150" alt="Victor J. Rosario V.'s Dev Card"/>
    </a>
</div>


----

## **FullStack Developer** 👨‍💻

<img src="https://media.giphy.com/media/VgCDAzcKvsR6OM0uWg/giphy.gif" width="50"> A little more about me...  In development

## npm
```sh
npx victor1890
```

```js
const victor1890 = {
    code: ["Javascript", "Typescript", "C#", "C", "C++", "Java", "Dart"],
    askMeAbout: ["Responsible", "Organized", "Social", "Fast Learning", "Collaborator / Contributor"],
    technologies: {
        mobileApp: ["React-Native", "Flutter"], //bacis
        frontend: {
            js: ["React", "NextJs", "VanillaJs"],
            css: ["Materialize", "Material-UI", "Bootstrap", "Tailwind"]
        },
        backend: {
            [js || ts]: ["Node", "Express", "GraphQL", "TypeORM", "Deno", "Golang"], //basic Deno
            asp: ["ASP.Net Core"]
        },
        databases: ["SQL Server", "SQLite", "Firebase", "MongoDB", "PostgreSQL", "Redis"]
    }
};
```

----

## **What I Use**


<table>
  <tbody>
    <!-- 1 -->
    <tr valign="top">
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/html-5.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/css-3.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/javascript.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/typescript-icon.svg">
      </td>
    </tr>
    <!-- 2 -->
    <tr valign="top">
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/react.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/nextjs.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/dotnet.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/nodejs.svg">
      </td>
    </tr>
    <!-- 3 -->
    <tr valign="top">
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/visual-studio-code.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/visual-studio.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/git-icon.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/npm.svg">
      </td>
    </tr>
    <tr valign="top">
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/wordpress-icon.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/express.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/mongodb.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/firebase.svg">
      </td>
    </tr>
    <tr valign="top">
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/tailwindcss-icon.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/bootstrap.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/materializecss.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/material-ui.svg">
      </td>
    </tr>
    <tr valign="top">
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/postgresql.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/typeorm.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/websocket.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/socket.io.svg">
      </td>
    </tr>
    <tr valign="top">
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/redis.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/go.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/rust.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/mysql-icon.svg">
      </td>
    </tr>
  </tbody>
</table>

<br/><br/>

## **📈 My GitHub Stats**x

<br />
<a href="https://github.com/victor1890/victor1890">
    <img align="center" src="https://github-readme-stats.vercel.app/api/top-langs/?username=victor1890&hide=csharp&layout=compact&langs_count=8" alt="Victor J. Rosario V. GitHub Stats"/>
</a>
<a href="https://github.com/victor1890/victor1890">
    <img align="center" src="https://github-readme-stats.vercel.app/api?username=victor1890&show_icons=true&line_height=27&count_private=true" alt="Victor J. Rosario V. GitHub Stats" />
</a>

<div>
    
  ![Snake animation](output/github-contribution-grid-snake.svg)
    
</div>

==> victor1890-2.1.1.tgz: package/README.md <==

## I'm **Victor J. Rosario V**


<div align='left'>
    <a href = "mailto:victorrosariodeveloper@gmail.com">
        <img src="https://img.shields.io/badge/-Gmail-%23333?style=for-the-badge&logo=gmail&logoColor=white" target="_blank">
    </a>
    <a href="https://www.linkedin.com/in/victor-j-rosario-v" target="_blank">
        <img src="https://img.shields.io/badge/-LinkedIn-%230077B5?style=for-the-badge&logo=linkedin&logoColor=white" target="_blank">
    </a>
    <a href='https://drive.google.com/file/d/1gNDOPcef5Q43_i40sR1YLPLoWuYDHwml/view?usp=sharing'>
        <img src='https://img.shields.io/badge/RESUME-CV-red?style=for-the-badge&logo=gmail&logoColor=white' target='_blank'/>
    </a>
</div>


<div align='right'>
    <img src="https://media.giphy.com/media/M9gbBd9nbDrOTu1Mqx/giphy.gif" width="150">
    <a href="https://app.daily.dev/Victor1890">
        <img src="https://api.daily.dev/devcards/773872eaf8514c99bbe1e8b17d69796b.png?r=p1o" width="150" alt="Victor J. Rosario V.'s Dev Card"/>
    </a>
</div>


----

## **FullStack Developer** 👨‍💻

<img src="https://media.giphy.com/media/VgCDAzcKvsR6OM0uWg/giphy.gif" width="50"> A little more about me...  In development

## npm
```sh
npx victor1890
```

```js
const victor1890 = {
    code: ["Javascript", "Typescript", "C#", "C", "C++", "Java", "Dart"],
    askMeAbout: ["Responsable", "Organized", "Social", "Fast Learning", "Collaboratod / Contributor"],
    technologies: {
        mobileApp: ["React-Native", "Flutter"], //bacis
        frontEnd: {
            js: ["React", "NextJs", "VanilaJs"],
            css: ["Materialize", "Material-UI", "Bootstrap", "Tailwind"]
        },
        backEnd: {
            [js && ts]: ["Node", "Express", "GraphQL", "TypeORM", "Deno"], //basic Deno
            asp: ["ASP.Net Core"]
        },
        databases: ["SQL Server", "SQLite", "Firebase", "MongoDB", "PostgreSQL"]
    }
};
```

----

## **What I Use**


<table>
  <tbody>
    <!-- 1 -->
    <tr valign="top">
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/html-5.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/css-3.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/javascript.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/typescript-icon.svg">
      </td>
    </tr>
    <!-- 2 -->
    <tr valign="top">
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/react.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/nextjs.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/dotnet.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/nodejs.svg">
      </td>
    </tr>
    <!-- 3 -->
    <tr valign="top">
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/visual-studio-code.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/visual-studio.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/git-icon.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/npm.svg">
      </td>
    </tr>
    <tr valign="top">
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/wordpress-icon.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/express.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/mongodb.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/firebase.svg">
      </td>
    </tr>
    <tr valign="top">
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/tailwindcss-icon.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/bootstrap.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/materializecss.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/material-ui.svg">
      </td>
    </tr>
    <tr valign="top">
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/postgresql.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/typeorm.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/websocket.svg">
      </td>
      <td width="25%" align="center">
        <br/><br/>
        <img height="64px" src="https://cdn.svgporn.com/logos/socket.io.svg">
      </td>
    </tr>
  </tbody>
</table>

<br/><br/>

## **📈 My GitHub Stats**

<br />
<a href="https://github.com/victor1890/victor1890">
    <img align="center" src="https://github-readme-stats.vercel.app/api/top-langs/?username=victor1890&hide=shaderlab,scss,makefile,cmake,java,dart,hlsl,c,r,shell,cpp&layout=compact" alt="Victor J. Rosario V. GitHub Stats"/>
</a>
<a href="https://github.com/victor1890/victor1890">
    <img align="center" src="https://github-readme-stats.vercel.app/api?username=victor1890&show_icons=true&line_height=27&count_private=true" alt="Victor J. Rosario V. GitHub Stats" />
</a>

<div>
    
  ![Snake animation](https://github.com/rafaballerini/rafaballerini/blob/output/github-contribution-grid-snake.svg)
    
</div>
